@@ -16,8 +16,14 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
+#include "fileio.h"
 #include "misc.h"
 #include <gdk/gdkkeysyms.h>
+#ifdef G_OS_WIN32
+# include <shlobj.h>
+# include <tchar.h>
+# include <windows.h>
+#endif /* G_OS_WIN32 */
 
 
 /******************************************************************************
@@ -198,6 +204,9 @@ misc_create_toolbar (MiscCreateToolbarEntry *entries)
                                                 GTK_ORIENTATION_HORIZONTAL);
   gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
   gtk_toolbar_set_tooltips (GTK_TOOLBAR (toolbar), TRUE);
+#if GTK_CHECK_VERSION(2,4,0)
+  gtk_toolbar_set_show_arrow (GTK_TOOLBAR (toolbar), FALSE);
+#endif /* GTK_CHECK_VERSION(2,4,0) */
   tooltips = gtk_tooltips_new ();
   for (i = 0; entries[i].path; i++)
     {
@@ -288,6 +297,175 @@ misc_find_toolbar (MiscCreateToolbarEntry *entries,
 }
 
 
+/******************************************************************************
+*                                                                             *
+* ja:特定ファイル関数群                                                       *
+*                                                                             *
+******************************************************************************/
+/*  ja:ユーザ設定ファイルを取得する
+    group,グループ
+     name,アプリケーション名
+     file,ファイル名
+      RET,ユーザ設定ファイル                                                */
+const gchar *
+misc_spec_config (const gchar *group,
+                  const gchar *name,
+                  const gchar *file)
+{
+  const static gchar *config = NULL;
+  gchar *filename;
+#if ! GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
+  LPITEMIDLIST pidl = NULL;
+#endif /* ! GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
+
+  if (config)
+    return config;
+#ifdef G_OS_WIN32
+  filename = g_strconcat (file, ".ini", NULL);
+# if GLIB_CHECK_VERSION(2,6,0)
+  config = g_build_filename (g_get_user_config_dir (),
+                                                group, name, filename, NULL);
+  if (!config)
+    {
+      LPITEMIDLIST pidl = NULL;
+# endif /* GLIB_CHECK_VERSION(2,6,0) */
+      if (SHGetSpecialFolderLocation (NULL, CSIDL_APPDATA, &pidl) == S_OK)
+        {
+# if ! GLIB_CHECK_VERSION(2,6,0)
+          TCHAR szPath[MAX_PATH + 1];
+# endif /* not GLIB_CHECK_VERSION(2,6,0) */
+
+# if GLIB_CHECK_VERSION(2,6,0)
+          if (G_WIN32_HAVE_WIDECHAR_API ())
+            {
+              WCHAR szPath[MAX_PATH + 1];
+# endif /* GLIB_CHECK_VERSION(2,6,0) */
+# if GLIB_CHECK_VERSION(2,6,0) || defined (UNICODE)
+              if (SHGetPathFromIDListW (pidl, szPath))
+                {
+                  gchar *utf8str;
+
+                  utf8str = g_utf16_to_utf8 (szPath, -1, NULL, NULL, NULL);
+                  if (utf8str)
+                    {
+                      gchar *dir;
+
+                      dir = g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL);
+                      g_free (utf8str);
+                      if (dir)
+                        {
+                          config = g_build_filename
+                                            (dir, group, name, filename, NULL);
+                          g_free (dir);
+                        }
+                    }
+                }
+# endif /* GLIB_CHECK_VERSION(2,6,0) || defined (UNICODE) */
+# if GLIB_CHECK_VERSION(2,6,0)
+            }
+          else
+            {
+              CHAR szPath[MAX_PATH + 1];
+# endif /* GLIB_CHECK_VERSION(2,6,0) */
+# if GLIB_CHECK_VERSION(2,6,0) || ! defined (UNICODE)
+              if (SHGetPathFromIDListA (pidl, szPath))
+#  if GLIB_CHECK_VERSION(2,6,0)
+                {
+                  gchar *utf8str;
+
+                  utf8str = g_locale_to_utf8 (szPath, -1, NULL, NULL, NULL);
+                  if (utf8str)
+                    {
+                      gchar *path;
+
+                      path = g_filename_from_utf8
+                                            (utf8str, -1, NULL, NULL, NULL);
+                      if (path)
+                        {
+                          config = g_build_filename
+                                        (path, group, name, filename, NULL);
+                          g_free (path);
+                        }
+                      g_free (utf8str);
+                    }
+                }
+#  else /* not GLIB_CHECK_VERSION(2,6,0) */
+                config = g_build_filename
+                                        (szPath, group, name, filename, NULL);
+#  endif /* not GLIB_CHECK_VERSION(2,6,0) */
+# endif /* GLIB_CHECK_VERSION(2,6,0) || ! defined (UNICODE) */
+# if GLIB_CHECK_VERSION(2,6,0)
+            }
+# endif /* GLIB_CHECK_VERSION(2,6,0) */
+          CoTaskMemFree (pidl);
+        }
+# if GLIB_CHECK_VERSION(2,6,0)
+    }
+# else /* not GLIB_CHECK_VERSION(2,6,0) */
+      else
+        {
+          config = NULL;
+        }
+# endif /* not GLIB_CHECK_VERSION(2,6,0) */
+  if (!config)
+    config = g_build_filename (g_get_home_dir (), group, name, filename, NULL);
+#else /* not G_OS_WIN32 */
+  gchar *dir;
+
+  dir = g_strconcat (".", group, NULL);
+  filename = g_strconcat (file, ".conf", NULL);
+  config = g_build_filename (g_get_home_dir (), dir, name, filename, NULL);
+  g_free (dir);
+#endif /* not G_OS_WIN32 */
+  g_free (filename);
+  return config;
+}
+
+
+/*  ja:ロケールのディレクトリを取得する
+    prgname,プログラム
+        RET,ロケールのディレクトリ                                          */
+const gchar *
+misc_spec_locale (const gchar *prgname)
+{
+#ifdef LOCALEDIR
+  return LOCALEDIR;
+#else /* not LOCALEDIR */
+  const static gchar *locale = NULL;
+  gchar *dirname, *path;
+# if GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
+  gchar *tmp;
+# endif /* GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
+
+  if (locale)
+    return locale;
+  path = fileio_get_full_path (prgname);
+  dirname = g_path_get_dirname (path);
+  g_free (path);
+  locale = g_build_filename (dirname, "locale", NULL);
+  g_free (dirname);
+# ifdef G_OS_WIN32
+  if (!g_file_test (locale, G_FILE_TEST_EXISTS))
+    {
+      g_free (locale);
+      locale = g_win32_get_package_installation_subdirectory
+                            (NULL, prgname, "lib" G_DIR_SEPARATOR_S "locale");
+    }
+#  if GLIB_CHECK_VERSION(2,6,0)
+#   if GLIB_CHECK_VERSION(2,8,0)
+  tmp = g_win32_locale_filename_from_utf8 (locale);
+#   else /* not GLIB_CHECK_VERSION(2,8,0) */
+  tmp = g_locale_from_utf8 (locale, -1, NULL, NULL, NULL);
+#   endif /* not GLIB_CHECK_VERSION(2,8,0) */
+  g_free (locale);
+  locale = tmp;
+#  endif /* GLIB_CHECK_VERSION(2,6,0) */
+# endif /* G_OS_WIN32 */
+  return locale;
+#endif /* not LOCALEDIR */
+}
+
+
 /******************************************************************************
 *                                                                             *
 * ja:低レベル関数群                                                           *
@@ -788,7 +966,7 @@ misc_str_to_array (gsize          *size,
 {
   gchar *p;
   gpointer array = NULL;
-  gint i, j, value;
+  gint i, j;
 
   if (!size)
     return NULL;
@@ -800,15 +978,28 @@ misc_str_to_array (gsize          *size,
   for (i = 0; p[i] != '\0'; i++)
     {
       for (j = 0; j < radix; j++)
-        if (p[i] == hex[j])
+        if (g_ascii_toupper (p[i]) == hex[j])
           break;
       if (j >= radix)
-        p[i] = '\0';
+        p[i] = ' ';
     }
-  p[i + 1] = '\0';
+  i = j = 0;
+  while (p[i] != '\0')
+    if (p[i] == ' ')
+      {
+        if (p[++i] != ' ')
+          p[j++] = '\0';
+      }
+    else
+      {
+        p[j++] = p[i++];
+      }
+  p[j] = p[j + 1] = '\0';
   i = 0;
   while (p[i] != '\0')
     {
+      gint value;
+
       if (!misc_str_to_val (&value, p + i, radix, flag))
         {
           g_free (p);
