@@ -269,7 +269,7 @@ orz_history_add_file (OrzHistory  *history,
                                                             NULL, NULL, NULL);
 #endif /* not GLIB_CHECK_VERSION(2,6,0) */
           pixbuf = fileio_extract_icon (history_item->file,
-                                                    FILEIO_ICON_SIZE_SMALL);
+                                                        GTK_ICON_SIZE_MENU);
           if (pixbuf)
             {
               history_item->menu_item = gtk_image_menu_item_new_with_label
