@@ -205,9 +205,6 @@ print_out (TmaidWindow *tmaid,
   gc = gdk_gc_new (pixmap);
   gdk_gc_set_line_attributes (gc, 1,
                                 GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
-  for (i = 10; i < 12; i++)
-    gdk_color_alloc (gdk_colormap_get_system (), (tmaid->ft.syscol
-                                        ? system_color : tmaid->ft.color) + i);
   /* ja:ダイアログボックス */
   userbreak = TRUE;
   dialog = abort_dialog (_("Printing"));
