@@ -133,7 +133,7 @@ MiscCreateMenuEntry menu_entries[] = {
 {"/search/next",        GTK_STOCK_FIND_AND_REPLACE,    "<control>H",  NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_replace,  NULL,                    NULL},
 {"/option",             N_("_Option"),                 NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL,                    NULL},
 {"/option/",            NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL,                    NULL},
-{"/option/preferences", GTK_STOCK_PREFERENCES,         NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_conf,     NULL,                    NULL},
+{"/option/preferences", GTK_STOCK_PREFERENCES,         NULL,          NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_pref,     NULL,                    NULL},
 {"/option/file",        N_("File _Type"),              NULL,          filetype16_xpm,   MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_format,   NULL,                    NULL},
 {"/window",             N_("_Window"),                 NULL,          NULL,             MISC_CREATE_MENU_ITEM,                              NULL,             NULL,                    NULL},
 {"/window/",            NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SHELL,                             NULL,             NULL,                    NULL},
@@ -194,16 +194,7 @@ main (int   argc,
       char *argv[])
 {
   gboolean *arg_files, success[12];
-  gchar *user_config = NULL;
-#if ! GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
-  LPITEMIDLIST pidl = NULL;
-#endif /* ! GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
-#ifndef LOCALEDIR
-  gchar *dirname, *path, *locale;
-# if GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
-  gchar *temp;
-# endif /* GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
-#endif /* not LOCALEDIR */
+  const gchar *user_config;
   gsize length;
   gint i, count = 0, init_line = 0, license = -1;
   GKeyFile *key_file;
@@ -219,34 +210,7 @@ main (int   argc,
   setlocale (LC_ALL, "");
   gtk_set_locale ();
   gtk_init (&argc, &argv);
-#ifdef LOCALEDIR
-  bindtextdomain (PACKAGE, LOCALEDIR);
-#else /* not LOCALEDIR */
-  path = fileio_get_full_path (argv[0]);
-  dirname = g_path_get_dirname (path);
-  g_free (path);
-  locale = g_build_filename (dirname, "locale", NULL);
-  g_free (dirname);
-# ifdef G_OS_WIN32
-  if (!g_file_test (locale, G_FILE_TEST_EXISTS))
-    {
-      g_free (locale);
-      locale = g_win32_get_package_installation_subdirectory
-                            (NULL, argv[0], "lib" G_DIR_SEPARATOR_S "locale");
-    }
-#  if GLIB_CHECK_VERSION(2,6,0)
-#   if GLIB_CHECK_VERSION(2,8,0)
-  temp = g_win32_locale_filename_from_utf8 (locale);
-#   else /* not GLIB_CHECK_VERSION(2,8,0) */
-  temp = g_locale_from_utf8 (locale, -1, NULL, NULL, NULL);
-#   endif /* not GLIB_CHECK_VERSION(2,8,0) */
-  g_free (locale);
-  locale = temp;
-#  endif /* GLIB_CHECK_VERSION(2,6,0) */
-# endif /* G_OS_WIN32 */
-  bindtextdomain (PACKAGE, locale);
-  g_free (locale);
-#endif /* not LOCALEDIR */
+  bindtextdomain (PACKAGE, misc_spec_locale (argv[0]));
   bind_textdomain_codeset (PACKAGE, "UTF-8");
   textdomain (PACKAGE);
 
@@ -257,39 +221,7 @@ main (int   argc,
   history = orz_history_new ();
 
   /* ja:キーファイルを求める */
-#ifdef G_OS_WIN32
-# if GLIB_CHECK_VERSION(2,6,0)
-  user_config = g_build_filename (g_get_user_config_dir (),
-                                    "maid.org", "tmaid", "tmaid.ini", NULL);
-# else /* not GLIB_CHECK_VERSION(2,6,0) */
-  if (SHGetSpecialFolderLocation (NULL, CSIDL_APPDATA, &pidl) == S_OK)
-    {
-      TCHAR szPath[MAX_PATH + 1];
-
-      if (SHGetPathFromIDList (pidl, szPath))
-#  ifdef UNICODE
-        {
-          gchar *dir, *utf8str;
-
-          utf8str = g_utf16_to_utf8 (szPath, -1, NULL, NULL, NULL);
-          dir = g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL);
-          g_free (utf8str);
-          user_config = g_build_filename (dir,
-                                    "maid.org", "tmaid", "tmaid.ini", NULL);
-          g_free (dir);
-        }
-#  else /* not UNICODE */
-        user_config = g_build_filename (szPath,
-                                    "maid.org", "tmaid", "tmaid.ini", NULL);
-#  endif /* not UNICODE */
-      CoTaskMemFree (pidl);
-    }
-  if (!user_config)
-    user_config = g_build_filename (g_get_home_dir (), "tmaid.ini", NULL);
-# endif /* not GLIB_CHECK_VERSION(2,6,0) */
-#else /* not G_OS_WIN32 */
-  user_config = g_build_filename (g_get_home_dir (), ".tmaid", NULL);
-#endif /* not G_OS_WIN32 */
+  user_config = misc_spec_config ("maid.org", "tmaid", "main");
 
   /* ja:レジストリから読み出す */
   key_file = g_key_file_new ();
@@ -297,16 +229,14 @@ main (int   argc,
     {
       gchar *utf8str;
 
-      license = g_key_file_get_integer (key_file, "tmaid", "license", NULL);
+      license = g_key_file_get_integer (key_file, "license", "hash", NULL);
       orz_history_set_num (ORZ_HISTORY (history),
-                g_key_file_get_integer (key_file, "tmaid", "history", NULL));
-      newfile = g_key_file_get_boolean (key_file, "tmaid", "newfile", NULL);
-      second = g_key_file_get_boolean (key_file, "tmaid", "second", NULL);
-      def_width = g_key_file_get_integer (key_file, "tmaid", "def_width",
-                                                                        NULL);
-      def_height = g_key_file_get_integer (key_file, "tmaid", "def_height",
-                                                                        NULL);
-      n_pos = g_key_file_get_integer (key_file, "tmaid", "n_pos", NULL);
+                g_key_file_get_integer (key_file, "pref", "history", NULL));
+      newfile = g_key_file_get_boolean (key_file, "pref", "newfile", NULL);
+      second = g_key_file_get_boolean (key_file, "pref", "second", NULL);
+      def_width = g_key_file_get_integer (key_file, "pref", "width", NULL);
+      def_height = g_key_file_get_integer (key_file, "pref", "height", NULL);
+      n_pos = g_key_file_get_integer (key_file, "pref", "n_pos", NULL);
       ftnum = g_key_file_get_integer (key_file, "tmaid", "ftnum", NULL);
 #if GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32)
       findex = g_key_file_get_integer (key_file, "tmaid", "findex", NULL);
@@ -324,8 +254,8 @@ main (int   argc,
         {
           gchar *key;
 
-          key = g_strdup_printf ("history%d", i);
-          utf8str = g_key_file_get_string (key_file, "tmaid", key, NULL);
+          key = g_strdup_printf ("file%d", i);
+          utf8str = g_key_file_get_string (key_file, "history", key, NULL);
           g_free (key);
           if (utf8str)
             {
@@ -338,17 +268,16 @@ main (int   argc,
             }
         }
       /* ja:検索 */
-      find_arrow = g_key_file_get_boolean (key_file, "tmaid", "find_arrow",
-                                                                        NULL);
+      find_arrow = g_key_file_get_boolean (key_file, "find", "arrow", NULL);
       find_ignorecase = g_key_file_get_boolean (key_file,
-                                            "tmaid", "find_ignorecase", NULL);
-      find_num = g_key_file_get_integer (key_file, "tmaid", "find_num", NULL);
+                                                "find", "ignorecase", NULL);
+      find_num = g_key_file_get_integer (key_file, "find", "num", NULL);
       for (i = 0; i < find_num; i++)
         {
           gchar *key;
 
-          key = g_strdup_printf ("find%02d", i);
-          find_text[i] = g_key_file_get_string (key_file, "tmaid", key, NULL);
+          key = g_strdup_printf ("text%02d", i);
+          find_text[i] = g_key_file_get_string (key_file, "find", key, NULL);
           g_free (key);
           if (!find_text[i])
             break;
@@ -356,17 +285,16 @@ main (int   argc,
       find_num = i;
       /* ja:置換 */
       replace_arrow = g_key_file_get_boolean (key_file,
-                                            "tmaid", "replace_arrow", NULL);
+                                                    "replace", "arrow", NULL);
       replace_ignorecase = g_key_file_get_boolean (key_file,
-                                        "tmaid", "replace_ignorecase", NULL);
-      replace_num = g_key_file_get_integer (key_file, "tmaid", "replace_num",
-                                                                        NULL);
+                                                "replace", "ignorecase", NULL);
+      replace_num = g_key_file_get_integer (key_file, "replace", "num", NULL);
       for (i = 0; i < replace_num; i++)
         {
           gchar *key;
 
-          key = g_strdup_printf ("replace%02d", i);
-          replace_text[i] = g_key_file_get_string (key_file, "tmaid", key,
+          key = g_strdup_printf ("text%02d", i);
+          replace_text[i] = g_key_file_get_string (key_file, "replace", key,
                                                                         NULL);
           g_free (key);
           if (!replace_text[i])
@@ -539,7 +467,7 @@ main (int   argc,
   /* ja:コマンドラインの解析 */
   {
     gint array[2], def[2];
-    ArgumentBool arg_n, arg_x;
+    ArgumentBool arg_n, arg_p, arg_x;
     ArgumentValue arg_h, arg_l;
     ArgumentArray arg_s;
     ArgumentExit arg_v;
@@ -548,6 +476,7 @@ main (int   argc,
 {"history", 'h',  "NUM",          N_("History"),        ARGUMENT_TYPE_VALUE, &arg_h},
 {"line",    'l',  "NUM",          N_("Caret Position"), ARGUMENT_TYPE_VALUE, &arg_l},
 {"new",     'n',  "ON/OFF",       N_("New File"),       ARGUMENT_TYPE_BOOL,  &arg_n},
+{"profile", 'p',  "ON/OFF",       N_("Profile"),     ARGUMENT_TYPE_BOOL,  &arg_p},
 {"size",    's',  "WIDTH,HEIGHT", N_("Window Size"),    ARGUMENT_TYPE_ARRAY, &arg_s},
 {"second",  'x',  "ON/OFF",       N_("Open Window"),    ARGUMENT_TYPE_BOOL,  &arg_x},
 {"version", 'v',  NULL,           N_("About"),          ARGUMENT_TYPE_EXIT,  &arg_v},
@@ -563,6 +492,9 @@ main (int   argc,
     /* ja:新規ファイル */
     arg_n.flag = newfile;
     arg_n.def = FALSE;
+    /* ja:レジストリ */
+    arg_p.flag = TRUE;
+    arg_p.def = TRUE;
     /* ja:ウインドウサイズ */
     array[0] = def_width;
     array[1] = def_height;
@@ -587,6 +519,8 @@ TMAID_COPYRIGHT_NOTICE"\n"
     if (arg_l.val >= 0)
       init_line = arg_l.val;
     newfile = arg_n.flag;
+    if (!arg_p.flag)
+      user_config = NULL;
     def_width = array[0];
     def_height = array[1];
     second = arg_x.flag;
@@ -795,14 +729,14 @@ TMAID_COPYRIGHT_NOTICE"\n"
 
       key_file = g_key_file_new ();
       g_key_file_load_from_file (key_file, user_config, G_KEY_FILE_NONE, NULL);
-      g_key_file_set_integer (key_file, "tmaid", "license", license);
-      g_key_file_set_integer (key_file, "tmaid", "history",
+      g_key_file_set_integer (key_file, "license", "hash", license);
+      g_key_file_set_integer (key_file, "pref", "history",
                                 orz_history_get_num (ORZ_HISTORY (history)));
-      g_key_file_set_boolean (key_file, "tmaid", "newfile", newfile);
-      g_key_file_set_boolean (key_file, "tmaid", "second", second);
-      g_key_file_set_integer (key_file, "tmaid", "def_width", def_width);
-      g_key_file_set_integer (key_file, "tmaid", "def_height", def_height);
-      g_key_file_set_integer (key_file, "tmaid", "n_pos", n_pos);
+      g_key_file_set_boolean (key_file, "pref", "newfile", newfile);
+      g_key_file_set_boolean (key_file, "pref", "second", second);
+      g_key_file_set_integer (key_file, "pref", "width", def_width);
+      g_key_file_set_integer (key_file, "pref", "height", def_height);
+      g_key_file_set_integer (key_file, "pref", "n_pos", n_pos);
       g_key_file_set_integer (key_file, "tmaid", "ftnum", ftnum);
 #if GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32)
       for (i = ftnum - 1; i >= 0; i--)
@@ -834,12 +768,12 @@ TMAID_COPYRIGHT_NOTICE"\n"
         {
           gchar *key;
 
-          key = g_strdup_printf ("history%d", i);
+          key = g_strdup_printf ("file%d", i);
           utf8str = g_filename_to_utf8 (g_list_nth_data (glist, i), -1,
                                                             NULL, NULL, NULL);
           if (utf8str)
             {
-              g_key_file_set_string (key_file, "tmaid", key, utf8str);
+              g_key_file_set_string (key_file, "history", key, utf8str);
               g_free (utf8str);
             }
           g_free (key);
@@ -849,51 +783,49 @@ TMAID_COPYRIGHT_NOTICE"\n"
         {
           gchar *key;
 
-          key = g_strdup_printf ("history%d", i++);
-          g_key_file_remove_key (key_file, "tmaid", key, NULL);
+          key = g_strdup_printf ("file%d", i++);
+          g_key_file_remove_key (key_file, "history", key, NULL);
           g_free (key);
         }
       /* ja:検索 */
-      g_key_file_set_boolean (key_file, "tmaid", "find_arrow", find_arrow);
-      g_key_file_set_boolean (key_file, "tmaid", "find_ignorecase",
-                                                            find_ignorecase);
-      g_key_file_set_integer (key_file, "tmaid", "find_num", find_num);
+      g_key_file_set_boolean (key_file, "find", "arrow", find_arrow);
+      g_key_file_set_boolean (key_file, "find", "ignorecase", find_ignorecase);
+      g_key_file_set_integer (key_file, "find", "num", find_num);
       for (i = 0; i < find_num; i++)
         {
           gchar *key;
 
-          key = g_strdup_printf ("find%02d", i);
-          g_key_file_set_string (key_file, "tmaid", key, find_text[i]);
+          key = g_strdup_printf ("text%02d", i);
+          g_key_file_set_string (key_file, "find", key, find_text[i]);
           g_free (key);
         }
       while (i < 32)
         {
           gchar *key;
 
-          key = g_strdup_printf ("find%02d", i++);
-          g_key_file_set_string (key_file, "tmaid", key, "");
+          key = g_strdup_printf ("text%02d", i++);
+          g_key_file_set_string (key_file, "find", key, "");
           g_free (key);
         }
       /* ja:置換 */
-      g_key_file_set_boolean (key_file, "tmaid", "replace_arrow",
-                                                                replace_arrow);
-      g_key_file_set_boolean (key_file, "tmaid", "replace_ignorecase",
+      g_key_file_set_boolean (key_file, "replace", "arrow", replace_arrow);
+      g_key_file_set_boolean (key_file, "replace", "ignorecase",
                                                         replace_ignorecase);
-      g_key_file_set_integer (key_file, "tmaid", "replace_num", replace_num);
+      g_key_file_set_integer (key_file, "replace", "num", replace_num);
       for (i = 0; i < replace_num; i++)
         {
           gchar *key;
 
-          key = g_strdup_printf ("replace%02d", i);
-          g_key_file_set_string (key_file, "tmaid", key, replace_text[i]);
+          key = g_strdup_printf ("text%02d", i);
+          g_key_file_set_string (key_file, "replace", key, replace_text[i]);
           g_free (key);
         }
       while (i < 32)
         {
           gchar *key;
 
-          key = g_strdup_printf ("replace%02d", i++);
-          g_key_file_set_string (key_file, "tmaid", key, "");
+          key = g_strdup_printf ("text%02d", i++);
+          g_key_file_set_string (key_file, "replace", key, "");
           g_free (key);
         }
       /* ja:印刷 */
@@ -1000,7 +932,6 @@ TMAID_COPYRIGHT_NOTICE"\n"
     }
 
   pango_font_description_free (system_font);
-  g_free (user_config);
   g_free (clipboard_text);
   g_free (open_path);
   g_free (save_path);
