@@ -32,8 +32,6 @@ extern "C" {
 #define TMAID_VERSION_NOTICE "Text maid "VERSION" ("BUILD_ENVIRONMENT")"
 #define TMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2006 Kazuki IWAMOTO"
 
-#define MENUFILE 12
-
 
 typedef struct _FileType
 {
@@ -85,7 +83,6 @@ typedef struct _TmaidWindow
   gint font_height;         /* ja:フォントの高さ */
   gint max;                 /* ja:行数 */
   gint off;                 /* ja:startが参照する行 */
-  gint same;                /* ja:-1:重複なし,0?:番号 */
   guint timer_id;           /* ja:スクロール用タイマ */
   guint8 font_buf[65536];   /* ja:文字幅のバッファ */
   FileType ft;              /* ja:ファイルタイプ */
@@ -134,11 +131,11 @@ extern GdkAtom atom_targets;            /* ja:ターゲット */
 extern GdkAtom atom_text;               /* ja:テキスト */
 extern GdkAtom atom_compound;           /* ja:コンパウンド */
 extern GdkAtom atom_utf8;               /* ja:UTF-8 */
+extern GtkPositionType n_pos;           /* ja:ノートブックの位置 */
 extern GtkWidget *window;               /* ja:ウインドウ */
 extern GtkWidget *mdi;                  /* en:MDI */
 extern GtkWidget *status;               /* ja:ステータスウインドウ */
 extern GtkWidget *label_cursor;         /* ja:カーソル座標 */
-extern GtkPositionType n_pos;           /* ja:ノートブックの位置 */
 extern PangoFontDescription *system_font;
 extern GdkColor system_color[12];
 extern GtkTargetEntry targets[4];   /* ja:Text maidが提供可能なセレクション */
